@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "p-search" "1.0.0"
-  "Emacs Search Tool Aggregator."
+(define-package "p-search" "20250802.538"
+  "Local Search Engine for Emacs."
   '((emacs  "29.1")
     (compat "29.1"))
   :url "https://github.com/zkry/p-search"
-  :commit "4cab2337796e92311894149d87f26f576b997298"
-  :revdesc "4cab2337796e"
+  :commit "c382c80947a95825e258332d6f89bd6be496d914"
+  :revdesc "c382c80947a9"
   :keywords '("tools"))
